@@ -516,17 +516,7 @@ void cpgolin(int maxpt, int *npt, float *x, float *y, int symbol)
 int cpgopen(const char *device)
 {
   int pgopen = giza_open_device(device,"giza");
- 
- /*  PGPLOT gets pgopen = id on success
-  *  and <= 0 for errors
-  */
- if (pgopen!=0) {
-    pgopen = -1;
- } else {
-    pgopen = 1;
- }
- return pgopen;
-
+  return pgopen;
 }
 
 /***************************************************************
@@ -549,7 +539,7 @@ void cpgpanl(int nxc, int nyc)
 
 /***************************************************************
  * cpgpap -- change the size of the view surface
- * Status: IMPLEMENTED (NOT WORKING)
+ * Status: IMPLEMENTED
  ***************************************************************/
 void cpgpap(float width, float aspect)
 {
@@ -728,11 +718,11 @@ void cpgqhs(float *angle, float *sepn, float* phase)
 
 /***************************************************************
  * cpgqid -- inquire current device identifier
- * Status: NOT IMPLEMENTED
+ * Status: IMPLEMENTED
  ***************************************************************/
 void cpgqid(int *id)
 {
-  *id = 1;
+  giza_get_device_id(id);
 }
 
 /***************************************************************
@@ -1026,11 +1016,11 @@ void cpgsitf(int itf)
 
 /***************************************************************
  * cpgslct -- select an open graphics device
- * Status: NOT IMPLEMENTED
+ * Status: IMPLEMENTED
  ***************************************************************/
 void cpgslct(int id)
 {
-
+  giza_select_device(id-1);
 }
 
 /***************************************************************
@@ -1084,17 +1074,17 @@ void cpgsvp(float xleft, float xright, float ybot, float ytop)
  ***************************************************************/
 void cpgswin(float x1, float x2, float y1, float y2)
 {
-  giza_set_window_float(x2, x2, y1, y2);
+  giza_set_window_float(x1, x2, y1, y2);
 }
 
 /***************************************************************
  * cpgtbox -- draw frame and write (dd) hh mm ss.s labelling
- * Status: NOT IMPLEMENTED
+ * Status: PARTIALLY IMPLEMENTED
  ***************************************************************/
 void cpgtbox(const char *xopt, float xtick, int nxsub, \
  const char *yopt, float ytick, int nysub)
 {
-
+  giza_box_time_float(xopt, xtick, nxsub, yopt, ytick, nysub);
 }
 
 /***************************************************************
