@@ -778,13 +778,6 @@ integer function PGOPEN (DEVICE)
 ! pgopen = giza_open_device_size(device,'giza',11.0,8.5,giza_units_inches)
  pgopen = giza_open_device(device,'giza')
  
- !--PGPLOT gets pgopen = id on success
- !  and <= 0 for errors
- if (pgopen.ne.0) then
-    pgopen = -1
- else
-    pgopen = 1
- endif
  call giza_set_colour_palette(giza_colour_palette_pgplot)
 
 end function PGOPEN
@@ -813,7 +806,7 @@ end subroutine PGPANL
 
 !------------------------------------------------------------------------
 ! Module: PGPAP -- change the size of the view surface 
-! Status: IMPLEMENTED (NOT WORKING)
+! Status: IMPLEMENTED
 !------------------------------------------------------------------------
 subroutine PGPAP (WIDTH, ASPECT)
  use giza, only:giza_set_paper_size, giza_units_inches
@@ -1078,13 +1071,14 @@ end subroutine PGQHS
 
 !------------------------------------------------------------------------
 ! Module: PGQID -- inquire current device identifier
-! Status: NOT IMPLEMENTED
+! Status: IMPLEMENTED
 !------------------------------------------------------------------------
 subroutine PGQID (ID)
+ use giza, only:giza_get_device_id
  implicit none
  integer, intent(out) :: ID
 
- ID = 1
+ call giza_get_device_id(ID)
 
 end subroutine PGQID
 
@@ -1525,11 +1519,14 @@ end subroutine PGSITF
 
 !------------------------------------------------------------------------
 ! Module: PGSLCT -- select an open graphics device
-! Status: NOT IMPLEMENTED
+! Status: IMPLEMENTED
 !------------------------------------------------------------------------
 subroutine PGSLCT(ID)
- implicit none
+ use giza, only:giza_select_device
  integer, intent(in) :: ID
+ integer :: ierr
+
+ call giza_select_device(ID)
 
 end subroutine PGSLCT
 
