@@ -15,7 +15,7 @@
 !  a) You must cause the modified files to carry prominent notices
 !     stating that you changed the files and the date of any change.
 !
-!  Copyright (C) 2005-2013 Daniel Price. All rights reserved.
+!  Copyright (C) 2005-2014 Daniel Price. All rights reserved.
 !  Contact: daniel.price@monash.edu
 !
 !-----------------------------------------------------------------
@@ -135,7 +135,7 @@ subroutine read_data(rootname,indexstart,nstepsread)
   integer, parameter :: ilocbinary = 24
   real,    parameter :: pi=3.141592653589
   integer :: i,j,k,ierr,iunit
-  integer :: intg1,int2,int3
+  integer :: intg1,int2,int3,ilocvx
   integer :: i1,iarr,i2,iptmass1,iptmass2,ilocpmassinitial
   integer :: npart_max,nstep_max,ncolstep,icolumn,nptmasstot
   integer :: narrsizes,nints,nreals,nreal4s,nreal8s
@@ -161,9 +161,10 @@ subroutine read_data(rootname,indexstart,nstepsread)
   real(doub_prec), dimension(:), allocatable :: dattemp
   real*4, dimension(:), allocatable :: dattempsingle
   real(doub_prec) :: r8
+  real(sing_prec) :: r4
   real, dimension(maxreal) :: dummyreal
   real, dimension(:,:), allocatable :: dattemp2
-  real :: rhozero,hfact,omega,r4,tff
+  real :: rhozero,hfact,omega,tff
   logical :: skip_corrupted_block_3
 
   nstepsread = 0
@@ -374,7 +375,12 @@ subroutine read_data(rootname,indexstart,nstepsread)
          read(iunit,end=55,iostat=ierr) dattemp(1:nreals)
          dummyreal(1:nreals) = real(dattemp(1:nreals))
       else
-         read(iunit,end=55,iostat=ierr) dummyreal(1:nreals)
+         if (allocated(dattempsingle)) deallocate(dattempsingle)
+         allocate(dattempsingle(nreals),stat=ierr)
+         if (ierr /=0) print*,'ERROR in memory allocation'
+         read(iunit,end=55,iostat=ierr) dattempsingle(1:nreals)
+         dummyreal(1:nreals) = real(dattempsingle(1:nreals))
+         deallocate(dattempsingle)
       endif
    endif
 !--real*4, real*8
@@ -625,7 +631,7 @@ subroutine read_data(rootname,indexstart,nstepsread)
          tff = 0.
       endif
       if (phantomdump) then
-         npartoftype(:,j) = 0.
+         npartoftype(:,j) = 0
          do i=1,ntypes !--map from phantom types to splash types
             itype = itypemap_phantom(int(i,kind=1))
             if (debug) print*,'DEBUG: npart of type ',itype,' += ',npartoftypei(i)
@@ -825,6 +831,7 @@ subroutine read_data(rootname,indexstart,nstepsread)
                nskip = nreal(iarr)
             else
                iphase(npart+1:npart+isize(iarr)) = -3
+               ilocvx = nreal(iarr)-2 ! velocity is always last 3 numbers for phantom sinks
                if (doubleprec) then
                   !--convert default real to single precision where necessary
                   if (debug) print*,'DEBUG: reading sink data, converting from double precision ',isize(iarr)
@@ -838,6 +845,7 @@ subroutine read_data(rootname,indexstart,nstepsread)
                      if (debug) print*,'DEBUG: reading sink array ',k,isize(iarr)
                      read(iunit,end=33,iostat=ierr) dattemp(1:isize(iarr))
                      if (ierr /= 0) print*,' ERROR during read of sink particle data, array ',k
+                     
                      select case(k)
                      case(1:3)
                         iloc = ix(k)
@@ -845,10 +853,12 @@ subroutine read_data(rootname,indexstart,nstepsread)
                         iloc = ipmass
                      case(5)
                         iloc = ih
-                     case(7:9)
-                        iloc = ivx + k-7
                      case default
-                        iloc = 0
+                        if (k >= ilocvx .and. k < ilocvx+3 .and. ivx > 0) then
+                           iloc = ivx + k-ilocvx ! put velocity into correct arrays
+                        else
+                           iloc = 0
+                        endif
                      end select
                      if (iloc.gt.size(dat(1,:,j))) then; print*,' error iloc = ',iloc,ivx; stop; endif
                      if (iloc.gt.0) then
@@ -860,7 +870,13 @@ subroutine read_data(rootname,indexstart,nstepsread)
                      endif
                   enddo
                else
-                  if (debug) print*,'DEBUG: reading sink data, directly into array ',isize(iarr)
+                  if (debug) print*,'DEBUG: reading sink data, converting from single precision ',isize(iarr)
+                  if (allocated(dattempsingle)) deallocate(dattempsingle)
+                  allocate(dattempsingle(isize(iarr)),stat=ierr)
+                  if (ierr /= 0) then
+                     print "(a)",'ERROR in memory allocation'
+                     return
+                  endif
                   do k=1,nreal(iarr)
                      select case(k)
                      case(1:3)
@@ -869,18 +885,19 @@ subroutine read_data(rootname,indexstart,nstepsread)
                         iloc = ipmass
                      case(5)
                         iloc = ih
-                     case(7:9)
-                        if (ivx.gt.0) then
-                           iloc = ivx + k - 7
+                     case default
+                        if (k >= ilocvx .and. k < ilocvx+3 .and. ivx > 0) then
+                           iloc = ivx + k-ilocvx ! put velocity into correct arrays
                         else
                            iloc = 0
                         endif
-                     case default
-                        iloc = 0
                      end select
                      if (iloc.gt.0) then
                         if (debug) print*,'DEBUG: reading sinks into ',npart+1,'->',npart+isize(iarr),iloc
-                        read(iunit,end=33,iostat=ierr) dat(npart+1:npart+isize(iarr),iloc,j)
+                        read(iunit,end=33,iostat=ierr) dattempsingle(1:isize(iarr))
+                        do i=1,isize(ierr)
+                           dat(npart+i,iloc,j) = real(dattempsingle(i))
+                        enddo
                         if (ierr /= 0) print*,' ERROR during read of sink particle data, array ',k
                      else
                         if (debug) print*,'DEBUG: skipping sink particle array ',k
@@ -911,7 +928,19 @@ subroutine read_data(rootname,indexstart,nstepsread)
                      print*,'WARNING: sink particle masses not read because no mass array allocated'
                   endif
                else
-                  read(iunit,end=33,iostat=ierr) (dat(listpm(i),ipmass,j),i=iptmass1,iptmass2)
+                  !--convert default real to double precision where necessary
+                  if (allocated(dattempsingle)) deallocate(dattempsingle)
+                  allocate(dattempsingle(isize(iarr)),stat=ierr)
+                  if (ierr /=0) print "(a)",'ERROR in memory allocation'
+                  read(iunit,end=33,iostat=ierr) dattempsingle(1:isize(iarr))
+                  if (nptmass.ne.isize(iarr)) print "(a)",'ERROR: nptmass.ne.block size'
+                  if (ipmass.gt.0) then
+                     do i=1,isize(iarr)
+                        dat(listpm(iptmass1+i-1),ipmass,j) = real(dattempsingle(i))
+                     enddo
+                  else
+                     print*,'WARNING: sink particle masses not read because no mass array allocated'
+                  endif
                endif
                nskip = nreal(iarr) - 1 + nreal4(iarr) + nreal8(iarr)
             endif
@@ -930,6 +959,10 @@ subroutine read_data(rootname,indexstart,nstepsread)
             if (allocated(dattemp)) deallocate(dattemp)
             allocate(dattemp(isize(iarr)),stat=ierr)
             if (ierr /=0) print "(a)",'ERROR in memory allocation (read_data_sphNG: dattemp)'
+         elseif (nreal(iarr).gt.0 .or. nreal8(iarr).gt.0) then
+            if (allocated(dattempsingle)) deallocate(dattempsingle)
+            allocate(dattempsingle(isize(iarr)),stat=ierr)
+            if (ierr /=0) print "(a)",'ERROR in memory allocation (read_data_sphNG: dattempsingle)'
          endif
 !        default reals may need converting
          do i=1,nreal(iarr)
@@ -950,7 +983,8 @@ subroutine read_data(rootname,indexstart,nstepsread)
                   read(iunit,end=33,iostat=ierr) dattemp(1:isize(iarr))
                   dat(i1:i2,icolumn,j) = real(dattemp(1:isize(iarr)))
                else
-                  read(iunit,end=33,iostat=ierr) dat(i1:i2,icolumn,j)
+                  read(iunit,end=33,iostat=ierr) dattempsingle(1:isize(iarr))
+                  dat(i1:i2,icolumn,j) = real(dattempsingle(1:isize(iarr)))
                endif
             else
                read(iunit,end=33,iostat=ierr)
